/*
  Example for Stepper 4 Click

  Date          : August 2017
  Author        : Irena Blagojevic

  Test configuration STM32 :
    
  MCU              : STM32F107VCT6
  Dev. Board       : EasyMx PRO v7 for STM32
  ARM Compiler ver : v.5.1.0

  Description :

  Demonstrates how to use Stepper 4 click to move a stepper motor. First
  the speed is set, given in number of steps per revolution. Afterwards
  the motor is moved using STEPPER_step function, passing it the number
  of desired steps. If that number is negative, the motor moves CCW,
  otherwise it moves CW.

*/

#include "MIKROBUS_framework.h"
#include "__STEPPER_Driver.h"


void InitTimer2()
{
    RCC_APB1ENR.TIM2EN = 1;
    TIM2_CR1.CEN = 0;
    TIM2_PSC = 0;
    TIM2_ARR = 7199;
    NVIC_IntEnable(IVT_INT_TIM2);
    TIM2_DIER.UIE = 1;
    TIM2_CR1.CEN = 1;
}

void systemInit()
{
    STEPPER_GPIOmap( MIKROBUS1_setAN, MIKROBUS1_setCS, MIKROBUS1_setPWM,
                     MIKROBUS1_setRST, MIKROBUS1_setINT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_AN_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_CS_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_PWM_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_RST_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_INT_PIN, GPIO_OUTPUT );

    InitTimer2();
}

void Stepper_4_Init()
{
    STEPPER_init( 200, 100 );

    STEPPER_setAcc( 5 );
    STEPPER_setDec( 5 );
}

void Stepper_4_Task()
{
    STEPPER_setSpeed( 200 );
    STEPPER_step( 400 );
    Delay_ms( 200 );
    STEPPER_setSpeed( 100 );
    STEPPER_step( -200 );
}

void main()
{
    systemInit();
    Stepper_4_Init();

    Stepper_4_Task();
}

void Timer2_interrupt() iv IVT_INT_TIM2 {
    TIM2_SR.UIF = 0;
    STEPPER_handler();
}
